#
# Makefile Template for Tessy
# Compiler   : Hitex GNU Cortex Version >= 4.4.0
# Targets    : HiTOP for LPC168-Stick, Tantino
# Modified   : Razorcat/Wittner/11.11.2009
# Startup code is added in linker command file main.ld
# Label _app_entry used in startup code and located in linker command file main.ld

# Defines to be generated by Tessy:
#
# TESSY_SYS          :=
# MODULE_PATH        :=
# TESTOBJECT         :=
# USER_LINK_OPTIONS  :=
# COMPILER_INSTALL_PATH :=
# TARGET_INSTALL_PATH   :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

TESSY_SYS     	:=	$(shell ts_pathname -s $(TESSY_SYS))
MODULE_PATH    :=	$(shell ts_pathname -s $(MODULE_PATH))

TESSY_SYS_DOS		:=	$(shell cygpath -w $(TESSY_SYS))
MODULE_PATH_DOS	:=	$(shell cygpath -w $(MODULE_PATH))
ARM_HOME				:=	$(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
HITOP_HOME			:= $(shell ts_pathname -s '$(TARGET_INSTALL_PATH)')
TS_HITOP_VERSION	:= 5


all : master slave

master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.elf

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE		:=	$(TESSY_SYS)/make/master_hitop_gnu_i386.mk
S_COMM_MAKE		:=	$(TESSY_SYS)/src/comm/comm_hitop_gnu_arm.mk


#
# SLAVE
# (You may change these settings to use your own compiler/linker options)
#
S_ASM_OPTIONS  := -mcpu=cortex-m3 -gdwarf2 -mthumb -EL
S_COMP_OPTIONS :=  -c -gdwarf-2 -MD -O0 -trigraphs -mcpu=cortex-m3 -mthumb -Wall  -fsigned-char \
							-mlittle-endian -xc -mno-thumb-interwork -mno-tpcs-frame -mlong-calls \
							-DTESSY -DTS_SLAVE -DTS_ARM -DTS_HITOP -DTS_HAVE_INT64 -DTS_HAVE_FLOAT64
S_LINK_OPTIONS	:= -T $(LINKER_FILE) -Map $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).map
S_LIBS			:= -L$(MODULE_PATH_DOS) -L$(ARM_HOME)\lib\gcc\arm-hitex-elf\$(ARM_VERSION)\thumb2 -L$(ARM_HOME)\arm-hitex-elf\lib\thumb2 -lgcc -lc
S_INCLUDES		:= -I$(TESSY_SYS_DOS)\include\tessy\comm -I$(MODULE_PATH_DOS)

S_ASM			:=	te -q $(ARM_HOME)\bin\arm-hitex-elf-as
S_CC			:=	te -q $(ARM_HOME)\bin\arm-hitex-elf-gcc
S_LINK			:=	te -q $(ARM_HOME)\bin\arm-hitex-elf-ld
S_OBJECTS  		:= $(MODULE_PATH_DOS)\tslows_hitop.o \
             		$(MODULE_PATH_DOS)\tstcomm.o \
             		$(MODULE_PATH_DOS)\tscoml.o

S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.o
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.o


#####################################################################
#END_DEFINES
#####################################################################

# Targets to be defined by Tessy
#
# for each source
#
# S_SRC_OBJECTS      := $(MODULE_PATH)/ts_src01.o ... ts_srcnn.o
# USER_COMP_OPTIONS* :=
# S_C1_OBJECTS       := $(MODULE_PATH)/ts_c1c01.o ... ts_c1cnn.o
#
# $(MODULE_PATH_DOS)/ts_src*.o : $(MODULE_PATH_DOS)/ts_src*.c
#     $(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $(USER_COMP_OPTIONS*) -o $@ -c $<
#
# $(MODULE_PATH_DOS)/ts_c1c*.o : $(MODULE_PATH_DOS)/ts_c1c*.c
#     $(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $(USER_COMP_OPTIONS*) -o $@ -c $<
#		@echo $@ >> $(MODULE_PATH_DOS)\ts_c1o

#####################################################################
#BEGIN_TARGETS
#####################################################################


# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o $@ -c $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o $@ -c $<

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
# COMPILE/LINK SLAVE
#


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.o : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -o $@ -c $<


$(MODULE_PATH_DOS)\start.o : $(PROJECTROOT)\tessy\config\startup.c
	@echo *
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -o $@ -c $<


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.elf : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.o \
                                          $(S_SRC_OBJECTS) \
                                          $(S_UC_OBJECT) \
                                          $(S_STUB_OBJECT) \
                                          $(S_C1_OBJECTS) \
                                          $(S_OBJECTS) \
             										$(MODULE_PATH_DOS)\start.o

	@echo *
	@echo ***** Compiling and Linking Slave *****

	$(S_LINK) $(S_LINK_OPTIONS) $(USER_LINK_OPTIONS) -o $@ $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.o \
	$(S_SRC_OBJECTS) $(S_UC_OBJECT) $(S_STUB_OBJECT) $(S_C1_OBJECTS) $(S_OBJECTS) $(S_LIBS)

#####################################################################
#END_TARGETS
#####################################################################












